.. historical-timelines documentation master file, created by
   sphinx-quickstart on Tue Apr  4 17:12:46 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

HistoricalEvent documentation
================================================

.. toctree::
   :maxdepth: 3
   :numbered:

.. autoclass:: historical_timelines.HistoricalEvent
   :members:

   get_random_event
